@@ -6,17 +6,23 @@ on the type of distribution/version we are dealing with.
 """
 import logging
 from ceph_deploy import exc
-from ceph_deploy.hosts import debian, centos, fedora, suse, remotes
+from ceph_deploy.util import versions
+from ceph_deploy.hosts import debian, centos, fedora, suse, remotes, rhel
 from ceph_deploy.connection import get_connection
 
 logger = logging.getLogger()
 
 
-def get(hostname, username=None, fallback=None, detect_sudo=True):
+def get(hostname,
+        username=None,
+        fallback=None,
+        detect_sudo=True,
+        use_rhceph=False,
+        callbacks=None):
     """
     Retrieve the module that matches the distribution of a ``hostname``. This
     function will connect to that host and retrieve the distribution
-    informaiton, then return the appropriate module and slap a few attributes
+    information, then return the appropriate module and slap a few attributes
     to that module defining the information it found from the hostname.
 
     For example, if host ``node1.example.com`` is an Ubuntu server, the
@@ -28,6 +34,13 @@ def get(hostname, username=None, fallback=None, detect_sudo=True):
 
     :param hostname: A hostname that is reachable/resolvable over the network
     :param fallback: Optional fallback to use if no supported distro is found
+    :param use_rhceph: Whether or not to install RH Ceph on a RHEL machine or
+                       the community distro.  Changes what host module is
+                       returned for RHEL.
+    :params callbacks: A list of callables that accept one argument (the actual
+                       module that contains the connection) that will be
+                       called, in order at the end of the instantiation of the
+                       module.
     """
     conn = get_connection(
         hostname,
@@ -48,21 +61,29 @@ def get(hostname, username=None, fallback=None, detect_sudo=True):
             release=release)
 
     machine_type = conn.remote_module.machine_type()
-    module = _get_distro(distro_name)
+    module = _get_distro(distro_name, use_rhceph=use_rhceph)
     module.name = distro_name
     module.normalized_name = _normalized_distro_name(distro_name)
     module.normalized_release = _normalized_release(release)
     module.distro = module.normalized_name
-    module.is_el = module.normalized_name in ['redhat', 'centos', 'fedora', 'scientific']
+    module.is_el = module.normalized_name in ['redhat', 'centos', 'fedora', 'scientific', 'oracle', 'virtuozzo']
+    module.is_rpm = module.normalized_name in ['redhat', 'centos',
+                                               'fedora', 'scientific', 'suse', 'oracle', 'virtuozzo']
+    module.is_deb = not module.is_rpm
     module.release = release
     module.codename = codename
     module.conn = conn
     module.machine_type = machine_type
-    module.init = module.choose_init()
+    module.init = module.choose_init(module)
+    module.packager = module.get_packager(module)
+    # execute each callback if any
+    if callbacks:
+        for c in callbacks:
+            c(module)
     return module
 
 
-def _get_distro(distro, fallback=None):
+def _get_distro(distro, fallback=None, use_rhceph=False):
     if not distro:
         return
 
@@ -72,12 +93,17 @@ def _get_distro(distro, fallback=None):
         'ubuntu': debian,
         'centos': centos,
         'scientific': centos,
+        'oracle' : centos,
         'redhat': centos,
         'fedora': fedora,
         'suse': suse,
+        'virtuozzo' : centos
         }
 
-    return distributions.get(distro) or _get_distro(fallback)
+    if distro == 'redhat' and use_rhceph:
+        return rhel
+    else:
+        return distributions.get(distro) or _get_distro(fallback)
 
 
 def _normalized_distro_name(distro):
@@ -86,10 +112,16 @@ def _normalized_distro_name(distro):
         return 'redhat'
     elif distro.startswith(('scientific', 'scientific linux')):
         return 'scientific'
+    elif distro.startswith('oracle'):
+        return 'oracle'
     elif distro.startswith(('suse', 'opensuse')):
         return 'suse'
     elif distro.startswith('centos'):
         return 'centos'
+    elif distro.startswith('linuxmint'):
+        return 'ubuntu'
+    elif distro.startswith('virtuozzo'):
+        return 'virtuozzo'
     return distro
 
 
@@ -105,21 +137,6 @@ def _normalized_release(release):
 
         normalized_version.int_major
     """
-    release = release.strip()
-
-    class NormalizedVersion(object):
-        pass
-    v = NormalizedVersion()  # fake object to get nice dotted access
-    v.major, v.minor, v.patch, v.garbage = (release.split('.') + ["0"]*4)[:4]
-    release_map = dict(major=v.major, minor=v.minor, patch=v.patch, garbage=v.garbage)
-
-    # safe int versions that remove non-numerical chars
-    # for example 'rc1' in a version like '1-rc1
-    for name, value in release_map.items():
-        if '-' in value:  # get rid of garbage like -dev1 or -rc1
-            value = value.split('-')[0]
-        value = float(''.join(c for c in value if c.isdigit()) or 0)
-        int_name = "int_%s" % name
-        setattr(v, int_name, value)
-
-    return v
+    # TODO: at some point deprecate this function so that we just
+    # use this class directly (and update every test that calls it
+    return versions.NormalizedVersion(release)
