@@ -1,10 +1,17 @@
-from ceph_deploy.util import pkg_managers, templates
+import logging
+from ceph_deploy.util import templates
 from ceph_deploy.lib import remoto
-from ceph_deploy.hosts.util import install_yum_priorities
+from ceph_deploy.hosts.common import map_components
+from ceph_deploy.util.paths import gpg
+from ceph_deploy.util import net
+
+
+LOG = logging.getLogger(__name__)
+NON_SPLIT_PACKAGES = ['ceph-osd', 'ceph-mon', 'ceph-mds']
 
 
 def rpm_dist(distro):
-    if distro.normalized_name in ['redhat', 'centos', 'scientific'] and distro.normalized_release.int_major >= 6:
+    if distro.normalized_name in ['redhat', 'centos', 'scientific', 'oracle', 'virtuozzo'] and distro.normalized_release.int_major >= 6:
         return 'el' + distro.normalized_release.major
     return 'el6'
 
@@ -28,48 +35,48 @@ def repository_url_part(distro):
     if distro.normalized_release.int_major >= 6:
         if distro.normalized_name == 'redhat':
             return 'rhel' + distro.normalized_release.major
-        if distro.normalized_name in ['centos', 'scientific']:
+        if distro.normalized_name in ['centos', 'scientific', 'oracle', 'virtuozzo']:
             return 'el' + distro.normalized_release.major
 
     return 'el6'
 
 
-def install(distro, version_kind, version, adjust_repos):
+def install(distro, version_kind, version, adjust_repos, **kw):
+    packages = map_components(
+        NON_SPLIT_PACKAGES,
+        kw.pop('components', [])
+    )
+
+    gpgcheck = kw.pop('gpgcheck', 1)
     logger = distro.conn.logger
-    release = distro.release
     machine = distro.machine_type
     repo_part = repository_url_part(distro)
     dist = rpm_dist(distro)
 
-    pkg_managers.yum_clean(distro.conn)
+    distro.packager.clean()
 
     # Get EPEL installed before we continue:
     if adjust_repos:
-        install_epel(distro)
-        install_yum_priorities(distro)
+        distro.packager.install('epel-release')
+        distro.packager.install('yum-plugin-priorities')
+        distro.conn.remote_module.enable_yum_priority_obsoletes()
+        logger.warning('check_obsoletes has been enabled for Yum priorities plugin')
     if version_kind in ['stable', 'testing']:
         key = 'release'
     else:
         key = 'autobuild'
 
     if adjust_repos:
-        if version_kind != 'dev':
-            remoto.process.run(
-                distro.conn,
-                [
-                    'rpm',
-                    '--import',
-                    "https://ceph.com/git/?p=ceph.git;a=blob_plain;f=keys/{key}.asc".format(key=key)
-                ]
-            )
+        if version_kind in ['stable', 'testing']:
+            distro.packager.add_repo_gpg_key(gpg.url(key))
 
             if version_kind == 'stable':
-                url = 'http://ceph.com/rpm-{version}/{repo}/'.format(
+                url = 'https://download.ceph.com/rpm-{version}/{repo}/'.format(
                     version=version,
                     repo=repo_part,
                     )
             elif version_kind == 'testing':
-                url = 'http://ceph.com/rpm-testing/{repo}/'.format(repo=repo_part)
+                url = 'https://download.ceph.com/rpm-testing/{repo}/'.format(repo=repo_part)
 
             remoto.process.run(
                 distro.conn,
@@ -81,79 +88,78 @@ def install(distro, version_kind, version, adjust_repos):
                 ],
             )
 
-        if version_kind == 'dev':
+        elif version_kind in ['dev', 'dev_commit']:
             logger.info('skipping install of ceph-release package')
             logger.info('repo file will be created manually')
+            shaman_url = 'https://shaman.ceph.com/api/repos/ceph/{version}/{sha1}/{distro}/{distro_version}/repo/?arch={arch}'.format(
+                distro=distro.normalized_name,
+                distro_version=distro.normalized_release.major,
+                version=kw['args'].dev,
+                sha1=kw['args'].dev_commit or 'latest',
+                arch=machine
+                )
+            LOG.debug('fetching repo information from: %s' % shaman_url)
+            content = net.get_chacra_repo(shaman_url)
             mirror_install(
                 distro,
-                'http://gitbuilder.ceph.com/ceph-rpm-centos{release}-{machine}-basic/ref/{version}/'.format(
-                    release=release.split(".", 1)[0],
-                    machine=machine,
-                    version=version),
-                "https://ceph.com/git/?p=ceph.git;a=blob_plain;f=keys/{key}.asc".format(key=key),
+                '',  # empty repo_url
+                None,  # no need to use gpg here, repos are unsigned
                 adjust_repos=True,
-                extra_installs=False
+                extra_installs=False,
+                gpgcheck=gpgcheck,
+                repo_content=content
             )
 
+        else:
+            raise Exception('unrecognized version_kind %s' % version_kind)
+
         # set the right priority
         logger.warning('ensuring that /etc/yum.repos.d/ceph.repo contains a high priority')
         distro.conn.remote_module.set_repo_priority(['Ceph', 'Ceph-noarch', 'ceph-source'])
         logger.warning('altered ceph.repo priorities to contain: priority=1')
 
-    remoto.process.run(
-        distro.conn,
-        [
-            'yum',
-            '-y',
-            'install',
-            'ceph',
-        ],
+    if packages:
+        distro.packager.install(packages)
+
+
+def mirror_install(distro, repo_url, gpg_url, adjust_repos, extra_installs=True, **kw):
+    packages = map_components(
+        NON_SPLIT_PACKAGES,
+        kw.pop('components', [])
     )
-
-
-def install_epel(distro):
-    """
-    CentOS and Scientific need the EPEL repo, otherwise Ceph cannot be
-    installed.
-    """
-    if distro.normalized_name in ['centos', 'scientific']:
-        distro.conn.logger.info('adding EPEL repository')
-        pkg_managers.yum(distro.conn, 'epel-release')
-
-
-def mirror_install(distro, repo_url, gpg_url, adjust_repos, extra_installs=True):
     repo_url = repo_url.strip('/')  # Remove trailing slashes
-    gpg_url_path = gpg_url.split('file://')[-1]  # Remove file if present
+    gpgcheck = kw.pop('gpgcheck', 1)
 
-    pkg_managers.yum_clean(distro.conn)
+    distro.packager.clean()
 
     if adjust_repos:
-        remoto.process.run(
-            distro.conn,
-            [
-                'rpm',
-                '--import',
-                gpg_url_path,
-            ]
-        )
+        if gpg_url:
+            distro.packager.add_repo_gpg_key(gpg_url)
 
         ceph_repo_content = templates.ceph_repo.format(
             repo_url=repo_url,
-            gpg_url=gpg_url
+            gpg_url=gpg_url,
+            gpgcheck=gpgcheck,
         )
+        content = kw.get('repo_content', ceph_repo_content)
 
-        distro.conn.remote_module.write_yum_repo(ceph_repo_content)
+        distro.conn.remote_module.write_yum_repo(content)
         # set the right priority
-        install_yum_priorities(distro)
+        if distro.packager.name == 'yum':
+            distro.packager.install('yum-plugin-priorities')
         distro.conn.remote_module.set_repo_priority(['Ceph', 'Ceph-noarch', 'ceph-source'])
-        distro.conn.logger.warning('alter.d ceph.repo priorities to contain: priority=1')
+        distro.conn.logger.warning('altered ceph.repo priorities to contain: priority=1')
 
 
-    if extra_installs:
-        pkg_managers.yum(distro.conn, 'ceph')
+    if extra_installs and packages:
+        distro.packager.install(packages)
 
 
 def repo_install(distro, reponame, baseurl, gpgkey, **kw):
+    packages = map_components(
+        NON_SPLIT_PACKAGES,
+        kw.pop('components', [])
+    )
     logger = distro.conn.logger
     # Get some defaults
     name = kw.pop('name', '%s repo' % reponame)
@@ -164,17 +170,10 @@ def repo_install(distro, reponame, baseurl, gpgkey, **kw):
     _type = 'repo-md'
     baseurl = baseurl.strip('/')  # Remove trailing slashes
 
-    pkg_managers.yum_clean(distro.conn)
+    distro.packager.clean()
 
     if gpgkey:
-        remoto.process.run(
-            distro.conn,
-            [
-                'rpm',
-                '--import',
-                gpgkey,
-            ]
-        )
+        distro.packager.add_repo_gpg_key(gpgkey)
 
     repo_content = templates.custom_repo(
         reponame=reponame,
@@ -197,11 +196,8 @@ def repo_install(distro, reponame, baseurl, gpgkey, **kw):
 
     # set the right priority
     if kw.get('priority'):
-        install_yum_priorities(distro)
-        logger.warning(
-            'ensuring that {repo_path} contains a high priority'.format(
-                repo_path=repo_path)
-        )
+        if distro.packager.name == 'yum':
+            distro.packager.install('yum-plugin-priorities')
 
         distro.conn.remote_module.set_repo_priority([reponame], repo_path)
         logger.warning('altered {reponame}.repo priorities to contain: priority=1'.format(
@@ -209,5 +205,5 @@ def repo_install(distro, reponame, baseurl, gpgkey, **kw):
         )
 
     # Some custom repos do not need to install ceph
-    if install_ceph:
-        pkg_managers.yum(distro.conn, 'ceph')
+    if install_ceph and packages:
+        distro.packager.install(packages)
