@@ -33,6 +33,8 @@ def platform_information(_linux_distribution=None):
                 codename = major
     if not codename and 'oracle' in distro.lower(): # this could be an empty string in Oracle linux
         codename = 'oracle'
+    if not codename and 'virtuozzo linux' in distro.lower(): # this could be an empty string in Virtuozzo linux
+        codename = 'virtuozzo'
 
     return (
         str(distro).rstrip(),
