@@ -17,7 +17,7 @@ def sanitize_args(args):
     not well suited for.
     """
     if args.release is None:
-        args.release = 'hammer'
+        args.release = 'jewel'
         args.default_release = True
 
     # XXX This whole dance is because --stable is getting deprecated
@@ -36,6 +36,7 @@ def detect_components(args, distro):
 
     * ceph
     * ceph-mon
+    * ceph-mgr
     * ceph-osd
     * ceph-mds
 
@@ -55,7 +56,9 @@ def detect_components(args, distro):
         'install_rgw': 'ceph-radosgw',
         'install_mds': 'ceph-mds',
         'install_mon': 'ceph-mon',
+        'install_mgr': 'ceph-mgr',
         'install_common': 'ceph-common',
+        'install_tests': 'ceph-test',
     }
 
     if distro.is_rpm:
@@ -84,6 +87,8 @@ def install(args):
     if args.repo:
         return install_repo(args)
 
+    gpgcheck = 0 if args.nogpgcheck else 1
+
     if args.version_kind == 'stable':
         version = args.release
     else:
@@ -146,6 +151,8 @@ def install(args):
             gpg_url = gpg_fallback
 
         if args.local_mirror:
+            if args.username:
+                hostname = "%s@%s" % (args.username, hostname)
             remoto.rsync(hostname, args.local_mirror, '/opt/ceph-deploy/repo', distro.conn.logger, sudo=True)
             repo_url = 'file:///opt/ceph-deploy/repo'
             gpg_url = 'file:///opt/ceph-deploy/repo/release.asc'
@@ -168,6 +175,8 @@ def install(args):
                 gpg_url,
                 args.adjust_repos,
                 components=components,
+                gpgcheck=gpgcheck,
+                args=args
             )
 
         # Detect and install custom repos here if needed
@@ -182,6 +191,8 @@ def install(args):
                 version,
                 args.adjust_repos,
                 components=components,
+                gpgcheck = gpgcheck,
+                args=args
             )
 
         # Check the ceph version we just installed
@@ -292,12 +303,15 @@ def install_repo(args):
 
         custom_repo(distro, args, cd_conf, rlogger, install_ceph=False)
 
-
-def uninstall(args):
+def remove(args, purge):
     LOG.info('note that some dependencies *will not* be removed because they can cause issues with qemu-kvm')
     LOG.info('like: librbd1 and librados2')
+    remove_action = 'Uninstalling'
+    if purge:
+        remove_action = 'Purging'
     LOG.debug(
-        'Uninstalling on cluster %s hosts %s',
+        '%s on cluster %s hosts %s',
+        remove_action,
         args.cluster,
         ' '.join(args.host),
         )
@@ -311,35 +325,15 @@ def uninstall(args):
             use_rhceph=True)
         LOG.info('Distro info: %s %s %s', distro.name, distro.release, distro.codename)
         rlogger = logging.getLogger(hostname)
-        rlogger.info('uninstalling Ceph on %s' % hostname)
-        distro.uninstall(distro)
+        rlogger.info('%s Ceph on %s' % (remove_action, hostname))
+        distro.uninstall(distro, purge=purge)
         distro.conn.exit()
 
+def uninstall(args):
+    remove(args, False)
 
 def purge(args):
-    LOG.info('note that some dependencies *will not* be removed because they can cause issues with qemu-kvm')
-    LOG.info('like: librbd1 and librados2')
-
-    LOG.debug(
-        'Purging from cluster %s hosts %s',
-        args.cluster,
-        ' '.join(args.host),
-        )
-
-    for hostname in args.host:
-        LOG.debug('Detecting platform for host %s ...', hostname)
-
-        distro = hosts.get(
-            hostname,
-            username=args.username,
-            use_rhceph=True
-        )
-        LOG.info('Distro info: %s %s %s', distro.name, distro.release, distro.codename)
-        rlogger = logging.getLogger(hostname)
-        rlogger.info('purging host ... %s' % hostname)
-        distro.uninstall(distro, purge=True)
-        distro.conn.exit()
-
+    remove(args, True)
 
 def purgedata(args):
     LOG.debug(
@@ -478,6 +472,13 @@ def make(parser):
         help='install a bleeding edge build from Git branch\
                 or tag (default: %(default)s)',
     )
+    parser.add_argument(
+        '--dev-commit',
+        nargs='?',
+        action=StoreVersion,
+        metavar='COMMIT',
+        help='install a bleeding edge build from Git commit (defaults to master branch)',
+    )
 
     version.set_defaults(
         stable=None,  # XXX deprecated in favor of release
@@ -493,6 +494,13 @@ def make(parser):
         help='install the mon component only',
     )
 
+    parser.add_argument(
+        '--mgr',
+        dest='install_mgr',
+        action='store_true',
+        help='install the mgr component only',
+    )
+
     parser.add_argument(
         '--mds',
         dest='install_mds',
@@ -514,6 +522,13 @@ def make(parser):
         help='install the osd component only',
     )
 
+    parser.add_argument(
+        '--tests',
+        dest='install_tests',
+        action='store_true',
+        help='install the testing components',
+    )
+
     parser.add_argument(
         '--cli', '--common',
         dest='install_common',
@@ -525,7 +540,7 @@ def make(parser):
         '--all',
         dest='install_all',
         action='store_true',
-        help='install all Ceph components (e.g. mon,osd,mds,rgw). This is the default',
+        help='install all Ceph components (mon, osd, mds, rgw) except tests. This is the default',
     )
 
     repo = parser.add_mutually_exclusive_group()
@@ -584,6 +599,12 @@ def make(parser):
                 (defaults to ceph.com)'
     )
 
+    parser.add_argument(
+        '--nogpgcheck',
+        action='store_true',
+        help='install packages without gpgcheck',
+    )
+
     parser.set_defaults(
         func=install,
     )
