@@ -1,5 +1,3 @@
-from cStringIO import StringIO
-import errno
 import logging
 import os
 
@@ -20,7 +18,7 @@ def get_bootstrap_mds_key(cluster):
     """
     path = '{cluster}.bootstrap-mds.keyring'.format(cluster=cluster)
     try:
-        with file(path, 'rb') as f:
+        with open(path, 'rb') as f:
             return f.read()
     except IOError:
         raise RuntimeError('bootstrap-mds keyring not found; run \'gatherkeys\'')
@@ -57,7 +55,7 @@ def create_mds(distro, name, cluster, init):
             os.path.join(keypath),
         ]
     )
-    if returncode > 0 and returncode != errno.EACCES:
+    if returncode > 0:
         for line in stderr:
             conn.logger.error(line)
         for line in stdout:
@@ -66,22 +64,6 @@ def create_mds(distro, name, cluster, init):
         conn.logger.error('exit code from command was: %s' % returncode)
         raise RuntimeError('could not create mds')
 
-        remoto.process.check(
-            conn,
-            [
-                'ceph',
-                '--cluster', cluster,
-                '--name', 'client.bootstrap-mds',
-                '--keyring', bootstrap_keyring,
-                'auth', 'get-or-create', 'mds.{name}'.format(name=name),
-                'osd', 'allow *',
-                'mds', 'allow',
-                'mon', 'allow rwx',
-                '-o',
-                os.path.join(keypath),
-            ]
-        )
-
     conn.remote_module.touch_file(os.path.join(path, 'done'))
     conn.remote_module.touch_file(os.path.join(path, init))
 
@@ -142,7 +124,7 @@ def create_mds(distro, name, cluster, init):
 
 
 def mds_create(args):
-    cfg = conf.ceph.load(args)
+    conf_data = conf.ceph.load_raw(args)
     LOG.debug(
         'Deploying mds, cluster %s hosts %s',
         args.cluster,
@@ -171,11 +153,9 @@ def mds_create(args):
             if hostname not in bootstrapped:
                 bootstrapped.add(hostname)
                 LOG.debug('deploying mds bootstrap to %s', hostname)
-                conf_data = StringIO()
-                cfg.write(conf_data)
                 distro.conn.remote_module.write_conf(
                     args.cluster,
-                    conf_data.getvalue(),
+                    conf_data,
                     args.overwrite_conf,
                 )
 
@@ -227,6 +207,7 @@ def make(parser):
     Ceph MDS daemon management
     """
     mds_parser = parser.add_subparsers(dest='subcommand')
+    mds_parser.required = True
 
     mds_create = mds_parser.add_parser(
         'create',
