@@ -7,8 +7,6 @@ import sys
 import time
 from textwrap import dedent
 
-from cStringIO import StringIO
-
 from ceph_deploy import conf, exc, hosts, mon
 from ceph_deploy.util import constants, system, packages
 from ceph_deploy.cliutil import priority
@@ -24,7 +22,7 @@ def get_bootstrap_osd_key(cluster):
     """
     path = '{cluster}.bootstrap-osd.keyring'.format(cluster=cluster)
     try:
-        with file(path, 'rb') as f:
+        with open(path, 'rb') as f:
             return f.read()
     except IOError:
         raise RuntimeError('bootstrap-osd keyring not found; run \'gatherkeys\'')
@@ -76,7 +74,7 @@ def osd_tree(conn, cluster):
     )
 
     try:
-        loaded_json = json.loads(''.join(out))
+        loaded_json = json.loads(b''.join(out).decode('utf-8'))
         # convert boolean strings to actual booleans because
         # --format=json fails to do this properly
         for k, v in loaded_json.items():
@@ -129,7 +127,7 @@ def osd_status_check(conn, cluster):
         return {}
 
     try:
-        loaded_json = json.loads(''.join(out))
+        loaded_json = json.loads(b''.join(out).decode('utf-8'))
         # convert boolean strings to actual booleans because
         # --format=json fails to do this properly
         for k, v in loaded_json.items():
@@ -189,7 +187,9 @@ def prepare_disk(
         fs_type,
         dmcrypt,
         dmcrypt_dir,
-        storetype):
+        storetype,
+        block_wal,
+        block_db):
     """
     Run on osd node, prepares a data disk for use.
     """
@@ -206,6 +206,13 @@ def prepare_disk(
         if dmcrypt_dir is not None:
             args.append('--dmcrypt-key-dir')
             args.append(dmcrypt_dir)
+    if storetype == 'bluestore':
+        if block_wal:
+            args.append('--block.wal')
+            args.append(block_wal)
+        if block_db:
+            args.append('--block.db')
+            args.append(block_db)
     if storetype:
         args.append('--' + storetype)
     args.extend([
@@ -302,11 +309,10 @@ def prepare(args, cfg, activate_prepared_disk):
                 bootstrapped.add(hostname)
                 LOG.debug('Deploying osd to %s', hostname)
 
-                conf_data = StringIO()
-                cfg.write(conf_data)
+                conf_data = conf.ceph.load_raw(args)
                 distro.conn.remote_module.write_conf(
                     args.cluster,
-                    conf_data.getvalue(),
+                    conf_data,
                     args.overwrite_conf
                 )
 
@@ -331,6 +337,8 @@ def prepare(args, cfg, activate_prepared_disk):
                 dmcrypt=args.dmcrypt,
                 dmcrypt_dir=args.dmcrypt_key_dir,
                 storetype=storetype,
+                block_wal=args.block_wal,
+                block_db=args.block_db
             )
 
             # give the OSD a few seconds to start
@@ -372,7 +380,7 @@ def activate(args, cfg):
 
         LOG.debug('activating host %s disk %s', hostname, disk)
         LOG.debug('will use init type: %s', distro.init)
-        
+
         ceph_disk_executable = system.executable_path(distro.conn, 'ceph-disk')
         remoto.process.run(
             distro.conn,
@@ -428,34 +436,6 @@ def disk_zap(args):
             ],
         )
 
-        # once all is done, call partprobe (or partx)
-        # On RHEL and CentOS distros, calling partprobe forces a reboot of the
-        # server. Since we are not resizing partitons we rely on calling
-        # partx
-        if distro.normalized_name.startswith(('centos', 'red')):
-            LOG.info('calling partx on zapped device %s', disk)
-            LOG.info('re-reading known partitions will display errors')
-            partx_executable = system.executable_path(distro.conn, 'partx')
-            remoto.process.run(
-                distro.conn,
-                [
-                    partx_executable,
-                    '-a',
-                    disk,
-                ],
-            )
-
-        else:
-            LOG.debug('Calling partprobe on zapped device %s', disk)
-            partprobe_executable = system.executable_path(distro.conn, 'partprobe')
-            remoto.process.run(
-                distro.conn,
-                [
-                    partprobe_executable,
-                    disk,
-                ],
-            )
-
         distro.conn.exit()
 
 
@@ -682,6 +662,7 @@ def make(parser):
     parser.description = sub_command_help
 
     osd_parser = parser.add_subparsers(dest='subcommand')
+    osd_parser.required = True
 
     osd_list = osd_parser.add_parser(
         'list',
@@ -708,11 +689,10 @@ def make(parser):
         '--fs-type',
         metavar='FS_TYPE',
         choices=['xfs',
-                 'ext4',
                  'btrfs'
                  ],
         default='xfs',
-        help='filesystem to use to format DISK (xfs, btrfs, or ext4)',
+        help='filesystem to use to format DISK (xfs, btrfs)',
         )
     osd_create.add_argument(
         '--dmcrypt',
@@ -730,6 +710,16 @@ def make(parser):
         action='store_true', default=None,
         help='bluestore objectstore',
         )
+    osd_create.add_argument(
+        '--block-db',
+        default=None,
+        help='bluestore block.db path'
+        )
+    osd_create.add_argument(
+        '--block-wal',
+        default=None,
+        help='bluestore block.wal path'
+        )
     osd_create.add_argument(
         'disk',
         nargs='+',
@@ -751,11 +741,10 @@ def make(parser):
         '--fs-type',
         metavar='FS_TYPE',
         choices=['xfs',
-                 'ext4',
                  'btrfs'
                  ],
         default='xfs',
-        help='filesystem to use to format DISK (xfs, btrfs, or ext4)',
+        help='filesystem to use to format DISK (xfs, btrfs)',
         )
     osd_prepare.add_argument(
         '--dmcrypt',
@@ -773,6 +762,16 @@ def make(parser):
         action='store_true', default=None,
         help='bluestore objectstore',
         )
+    osd_prepare.add_argument(
+        '--block-db',
+        default=None,
+        help='bluestore block.db path'
+        )
+    osd_prepare.add_argument(
+        '--block-wal',
+        default=None,
+        help='bluestore block.wal path'
+        )
     osd_prepare.add_argument(
         'disk',
         nargs='+',
@@ -803,6 +802,7 @@ def make_disk(parser):
     Manage disks on a remote host.
     """
     disk_parser = parser.add_subparsers(dest='subcommand')
+    disk_parser.required = True
 
     disk_zap = disk_parser.add_parser(
         'zap',
@@ -841,11 +841,10 @@ def make_disk(parser):
         '--fs-type',
         metavar='FS_TYPE',
         choices=['xfs',
-                 'ext4',
                  'btrfs'
                  ],
         default='xfs',
-        help='filesystem to use to format DISK (xfs, btrfs, or ext4)',
+        help='filesystem to use to format DISK (xfs, btrfs)',
         )
     disk_prepare.add_argument(
         '--dmcrypt',
@@ -863,6 +862,16 @@ def make_disk(parser):
         action='store_true', default=None,
         help='bluestore objectstore',
         )
+    disk_prepare.add_argument(
+        '--block-db',
+        default=None,
+        help='bluestore block.db path'
+        )
+    disk_prepare.add_argument(
+        '--block-wal',
+        default=None,
+        help='bluestore block.wal path'
+        )
     disk_prepare.add_argument(
         'disk',
         nargs='+',
